@@ -1,4 +1,4 @@
---hive CDM DDL Specification for OMOP Common Data Model 5.4
+--hive CDM DDL Specification for OMOP Common Data Model 5.3
 --HINT DISTRIBUTE ON KEY (person_id)
 CREATE TABLE @cdmDatabaseSchema.person (
 			person_id integer NOT NULL,
@@ -40,10 +40,10 @@ CREATE TABLE @cdmDatabaseSchema.visit_occurrence (
 			care_site_id integer NULL,
 			visit_source_value VARCHAR(50),
 			visit_source_concept_id integer NULL,
-			admitted_from_concept_id integer NULL,
-			admitted_from_source_value VARCHAR(50),
-			discharged_to_concept_id integer NULL,
-			discharged_to_source_value VARCHAR(50),
+			admitting_source_concept_id integer NULL,
+			admitting_source_value VARCHAR(50),
+			discharge_to_concept_id integer NULL,
+			discharge_to_source_value VARCHAR(50),
 			preceding_visit_occurrence_id integer NULL );
 --HINT DISTRIBUTE ON KEY (person_id)
 CREATE TABLE @cdmDatabaseSchema.visit_detail (
@@ -59,12 +59,12 @@ CREATE TABLE @cdmDatabaseSchema.visit_detail (
 			care_site_id integer NULL,
 			visit_detail_source_value VARCHAR(50),
 			visit_detail_source_concept_id Integer NULL,
-			admitted_from_concept_id Integer NULL,
-			admitted_from_source_value VARCHAR(50),
-			discharged_to_source_value VARCHAR(50),
-			discharged_to_concept_id integer NULL,
+			admitting_source_value VARCHAR(50),
+			admitting_source_concept_id Integer NULL,
+			discharge_to_source_value VARCHAR(50),
+			discharge_to_concept_id integer NULL,
 			preceding_visit_detail_id integer NULL,
-			parent_visit_detail_id integer NULL,
+			visit_detail_parent_id integer NULL,
 			visit_occurrence_id integer NOT NULL );
 --HINT DISTRIBUTE ON KEY (person_id)
 CREATE TABLE @cdmDatabaseSchema.condition_occurrence (
@@ -116,8 +116,6 @@ CREATE TABLE @cdmDatabaseSchema.procedure_occurrence (
 			procedure_concept_id integer NOT NULL,
 			procedure_date TIMESTAMP,
 			procedure_datetime TIMESTAMP,
-			procedure_end_date TIMESTAMP,
-			procedure_end_datetime TIMESTAMP,
 			procedure_type_concept_id integer NOT NULL,
 			modifier_concept_id integer NULL,
 			quantity integer NULL,
@@ -137,17 +135,13 @@ CREATE TABLE @cdmDatabaseSchema.device_exposure (
 			device_exposure_end_date TIMESTAMP,
 			device_exposure_end_datetime TIMESTAMP,
 			device_type_concept_id integer NOT NULL,
-			unique_device_id VARCHAR(255),
-			production_id VARCHAR(255),
+			unique_device_id VARCHAR(50),
 			quantity integer NULL,
 			provider_id integer NULL,
 			visit_occurrence_id integer NULL,
 			visit_detail_id integer NULL,
 			device_source_value VARCHAR(50),
-			device_source_concept_id integer NULL,
-			unit_concept_id integer NULL,
-			unit_source_value VARCHAR(50),
-			unit_source_concept_id integer NULL );
+			device_source_concept_id integer NULL );
 --HINT DISTRIBUTE ON KEY (person_id)
 CREATE TABLE @cdmDatabaseSchema.measurement (
 			measurement_id integer NOT NULL,
@@ -169,10 +163,7 @@ CREATE TABLE @cdmDatabaseSchema.measurement (
 			measurement_source_value VARCHAR(50),
 			measurement_source_concept_id integer NULL,
 			unit_source_value VARCHAR(50),
-			unit_source_concept_id integer NULL,
-			value_source_value VARCHAR(50),
-			measurement_event_id integer NULL,
-			meas_event_field_concept_id integer NULL );
+			value_source_value VARCHAR(50) );
 --HINT DISTRIBUTE ON KEY (person_id)
 CREATE TABLE @cdmDatabaseSchema.observation (
 			observation_id integer NOT NULL,
@@ -192,10 +183,7 @@ CREATE TABLE @cdmDatabaseSchema.observation (
 			observation_source_value VARCHAR(50),
 			observation_source_concept_id integer NULL,
 			unit_source_value VARCHAR(50),
-			qualifier_source_value VARCHAR(50),
-			value_source_value VARCHAR(50),
-			observation_event_id integer NULL,
-			obs_event_field_concept_id integer NULL );
+			qualifier_source_value VARCHAR(50) );
 --HINT DISTRIBUTE ON KEY (person_id)
 CREATE TABLE @cdmDatabaseSchema.death (
 			person_id integer NOT NULL,
@@ -220,9 +208,7 @@ CREATE TABLE @cdmDatabaseSchema.note (
 			provider_id integer NULL,
 			visit_occurrence_id integer NULL,
 			visit_detail_id integer NULL,
-			note_source_value VARCHAR(50),
-			note_event_id integer NULL,
-			note_event_field_concept_id integer NULL );
+			note_source_value VARCHAR(50) );
 --HINT DISTRIBUTE ON RANDOM
 CREATE TABLE @cdmDatabaseSchema.note_nlp (
 			note_nlp_id integer NOT NULL,
@@ -272,11 +258,7 @@ CREATE TABLE @cdmDatabaseSchema.location (
 			state VARCHAR(2),
 			zip VARCHAR(9),
 			county VARCHAR(20),
-			location_source_value VARCHAR(50),
-			country_concept_id integer NULL,
-			country_source_value VARCHAR(80),
-			latitude FLOAT,
-			longitude FLOAT );
+			location_source_value VARCHAR(50) );
 --HINT DISTRIBUTE ON RANDOM
 CREATE TABLE @cdmDatabaseSchema.care_site (
 			care_site_id integer NOT NULL,
@@ -369,35 +351,13 @@ CREATE TABLE @cdmDatabaseSchema.condition_era (
 			condition_era_start_date TIMESTAMP,
 			condition_era_end_date TIMESTAMP,
 			condition_occurrence_count integer NULL );
---HINT DISTRIBUTE ON KEY (person_id)
-CREATE TABLE @cdmDatabaseSchema.episode (
-			episode_id integer NOT NULL,
-			person_id integer NOT NULL,
-			episode_concept_id integer NOT NULL,
-			episode_start_date TIMESTAMP,
-			episode_start_datetime TIMESTAMP,
-			episode_end_date TIMESTAMP,
-			episode_end_datetime TIMESTAMP,
-			episode_parent_id integer NULL,
-			episode_number integer NULL,
-			episode_object_concept_id integer NOT NULL,
-			episode_type_concept_id integer NOT NULL,
-			episode_source_value VARCHAR(50),
-			episode_source_concept_id integer NULL );
---HINT DISTRIBUTE ON RANDOM
-CREATE TABLE @cdmDatabaseSchema.episode_event (
-			episode_id integer NOT NULL,
-			event_id integer NOT NULL,
-			episode_event_field_concept_id integer NOT NULL );
 --HINT DISTRIBUTE ON RANDOM
 CREATE TABLE @cdmDatabaseSchema.metadata (
-			metadata_id integer NOT NULL,
 			metadata_concept_id integer NOT NULL,
 			metadata_type_concept_id integer NOT NULL,
 			name VARCHAR(250),
 			value_as_string VARCHAR(250),
 			value_as_concept_id integer NULL,
-			value_as_number FLOAT,
 			metadata_date TIMESTAMP,
 			metadata_datetime TIMESTAMP );
 --HINT DISTRIBUTE ON RANDOM
@@ -411,7 +371,6 @@ CREATE TABLE @cdmDatabaseSchema.cdm_source (
 			source_release_date TIMESTAMP,
 			cdm_release_date TIMESTAMP,
 			cdm_version VARCHAR(10),
-			cdm_version_concept_id integer NOT NULL,
 			vocabulary_version VARCHAR(20) );
 --HINT DISTRIBUTE ON RANDOM
 CREATE TABLE @cdmDatabaseSchema.concept (
@@ -495,12 +454,6 @@ CREATE TABLE @cdmDatabaseSchema.drug_strength (
 			valid_end_date TIMESTAMP,
 			invalid_reason VARCHAR(1) );
 --HINT DISTRIBUTE ON RANDOM
-CREATE TABLE @cdmDatabaseSchema.cohort (
-			cohort_definition_id integer NOT NULL,
-			subject_id integer NOT NULL,
-			cohort_start_date TIMESTAMP,
-			cohort_end_date TIMESTAMP );
---HINT DISTRIBUTE ON RANDOM
 CREATE TABLE @cdmDatabaseSchema.cohort_definition (
 			cohort_definition_id integer NOT NULL,
 			cohort_definition_name VARCHAR(255),
@@ -508,4 +461,11 @@ CREATE TABLE @cdmDatabaseSchema.cohort_definition (
 			definition_type_concept_id integer NOT NULL,
 			cohort_definition_syntax VARCHAR(MAX),
 			subject_concept_id integer NOT NULL,
-			cohort_initiation_date TIMESTAMP );
\ No newline at end of file
+			cohort_initiation_date TIMESTAMP );
+--HINT DISTRIBUTE ON RANDOM
+CREATE TABLE @cdmDatabaseSchema.attribute_definition (
+			attribute_definition_id integer NOT NULL,
+			attribute_name VARCHAR(255),
+			attribute_description VARCHAR(MAX),
+			attribute_type_concept_id integer NOT NULL,
+			attribute_syntax VARCHAR(MAX) );
\ No newline at end of file
